@@ -7,7 +7,7 @@ from StringIO import StringIO
 from urlparse import urlparse
 from utils import json_to_py, get_faker
 
-__version_info__ = ('2', '6', '0')
+__version_info__ = ('3', '0', '0')
 __version__ = '.'.join(__version_info__)
 
 class CreateSendError(Exception):
@@ -26,35 +26,119 @@ class Unauthorized(CreateSendError): pass
 class NotFound(ClientError): pass
 class Unavailable(Exception): pass
 
+class ExpiredOAuthToken(Unauthorized):
+  """Raised for HTTP response code of 401, specifically when an OAuth
+  token has expired (Code: 121, Message: 'Expired OAuth Token')"""
+  pass
+
 class CreateSendBase(object):
-  def __init__(self):
+  auth_details = None
+
+  def __init__(self, auth):
     self.fake_web = False
+    self.auth(auth)
+
+  def authorize_url(self, client_id, redirect_uri, scope, state=None):
+    """Get the authorization URL for your application, given the application's
+    client_id, redirect_uri, scope, and optional state data."""
+    params = [
+      ('client_id', client_id),
+      ('redirect_uri', redirect_uri),
+      ('scope', scope)
+    ]
+    if state:
+      params.append(('state', state))
+    return "%s?%s" % (CreateSend.oauth_uri, urllib.urlencode(params))
+
+  def exchange_token(self, client_id, client_secret, redirect_uri, code):
+    """Exchange a provided OAuth code for an OAuth access token, 'expires in'
+    value and refresh token."""
+    params = [
+      ('grant_type', 'authorization_code'),
+      ('client_id', client_id),
+      ('client_secret', client_secret),
+      ('redirect_uri', redirect_uri),
+      ('code', code),
+    ]
+    response = self._post('', urllib.urlencode(params),
+      CreateSend.oauth_token_uri, "application/x-www-form-urlencoded", True)
+    access_token, expires_in, refresh_token = None, None, None
+    r = json_to_py(response)
+    if hasattr(r, 'error') and hasattr(r, 'error_description'):
+      err = "Error exchanging code for access token: "
+      err += "%s - %s" % (r.error, r.error_description)
+      raise Exception(err)
+    access_token, expires_in, refresh_token = r.access_token, r.expires_in, r.refresh_token
+    return [access_token, expires_in, refresh_token]
+
+  def auth(self, auth):
+    """Authenticate with the Campaign Monitor API using either OAuth or
+    an API key.
+
+    :param auth: A dictionary representing the authentication details to use.
+    This dictionary must take either of the following forms:
+
+    {'access_token': 'your access token', 'refresh_token': 'your refresh token'}
+
+    {'api_key': 'your api key'}
+    """
+    self.auth_details = auth
+
+  def refresh_token(self):
+    """Refresh an OAuth token given a refresh token."""
+    if (not self.auth_details or
+      not 'refresh_token' in self.auth_details or
+      not self.auth_details['refresh_token']):
+      raise Exception("auth_details['refresh_token'] does not contain a refresh token.")
+
+    refresh_token = self.auth_details['refresh_token']
+    params = [
+      ('grant_type', 'refresh_token'),
+      ('refresh_token', refresh_token)
+    ]
+    response = self._post('', urllib.urlencode(params),
+      CreateSend.oauth_token_uri, "application/x-www-form-urlencoded", True)
+    new_access_token, new_expires_in, new_refresh_token = None, None, None
+    r = json_to_py(response)
+    new_access_token, new_expires_in, new_refresh_token = r.access_token, r.expires_in, r.refresh_token
+    self.auth({
+      'access_token': new_access_token,
+      'refresh_token': new_refresh_token})
+    return [new_access_token, new_expires_in, new_refresh_token]
 
   def stub_request(self, expected_url, filename, status=None, body=None):
+    """Stub a web request for testing."""
     self.fake_web = True
     self.faker = get_faker(expected_url, filename, status, body)
 
-  def make_request(self, method, path, params={}, body="", username=None, password=None):
+  def make_request(self, method, path, params={}, body="", username=None,
+    password=None, base_uri=None, content_type=None, no_auth=None):
     headers = {
       'User-Agent': 'createsend-python-%s' % __version__,
       'Content-Type': 'application/json; charset=utf-8',
       'Accept-Encoding' : 'gzip, deflate' }
-    parsed_base_uri = urlparse(CreateSend.base_uri)
+    if content_type:
+      headers['Content-Type'] = content_type
+    parsed_base_uri = urlparse(CreateSend.base_uri if not base_uri else base_uri)
     """username and password should only be set when it is intended that
     the default basic authentication mechanism using the API key be 
     overridden (e.g. when using the apikey route with username and password)."""
     if username and password:
       headers['Authorization'] = "Basic %s" % base64.b64encode("%s:%s" % (username, password))
-    else:
-      # Allow api_key to be set for a CreateSend instance.
-      headers['Authorization'] = "Basic %s" % base64.b64encode("%s:x" % (CreateSend.api_key or self.api_key))
+    elif self.auth_details:
+      if 'api_key' in self.auth_details and self.auth_details['api_key']:
+        headers['Authorization'] = "Basic %s" % base64.b64encode("%s:x" % self.auth_details['api_key'])
+      elif 'access_token' in self.auth_details and self.auth_details['access_token']:
+        headers['Authorization'] = "Bearer %s" % self.auth_details['access_token']
+    if no_auth:
+      del headers['Authorization']
     self.headers = headers
 
     """If in fake web mode (i.e. self.stub_request has been called), 
     self.faker should be set, and this request should be treated as a fake."""
     if self.fake_web:
       # Check that the actual url which would be requested matches self.faker.url. 
-      actual_url = "http://%s%s" % (parsed_base_uri.netloc, self.build_url(parsed_base_uri, path, params))
+      actual_url = "https://%s%s" % (parsed_base_uri.netloc, self.build_url(parsed_base_uri, path, params))
       self.faker.actual_url = actual_url
       if self.faker.url != actual_url:
         raise Exception("Faker's expected URL (%s) doesn't match actual URL (%s)" % (self.faker.url, actual_url))
@@ -63,7 +147,7 @@ class CreateSendBase(object):
       if self.faker.body is not None:
         if self.faker.body != body:
           raise Exception("Faker's expected body (%s) doesn't match actual body (%s)" % (self.faker.body, body))
-        
+
       data = self.faker.open() if self.faker else ''
       status = self.faker.status if (self.faker and self.faker.status) else 200
       return self.handle_response(status, data)
@@ -88,7 +172,10 @@ class CreateSendBase(object):
     if status == 400:
       raise BadRequest(json_to_py(data))
     elif status == 401:
-      raise Unauthorized(json_to_py(data))
+      json_data = json_to_py(data)
+      if json_data.Code == 121:
+        raise ExpiredOAuthToken(json_data)
+      raise Unauthorized(json_data)
     elif status == 404:
       raise NotFound()
     elif status in range(400, 500):
@@ -100,8 +187,9 @@ class CreateSendBase(object):
   def _get(self, path, params={}, username=None, password=None):
     return self.make_request(path=path, method="GET", params=params, username=username, password=password)
 
-  def _post(self, path, body=""):
-    return self.make_request(path=path, method="POST", body=body)
+  def _post(self, path, body="", base_uri=None, content_type=None, no_auth=None):
+    return self.make_request(path=path, method="POST", body=body, 
+      base_uri=base_uri, content_type=content_type)
 
   def _put(self, path, body="", params={}):
     return self.make_request(path=path, method="PUT", params=params, body=body)
@@ -111,8 +199,12 @@ class CreateSendBase(object):
 
 class CreateSend(CreateSendBase):
   """Provides high level CreateSend functionality/data you'll probably need."""
-  base_uri = "http://api.createsend.com/api/v3"
-  api_key = ""
+  base_uri = "https://api.createsend.com/api/v3"
+  oauth_uri = "https://api.createsend.com/oauth"
+  oauth_token_uri = "%s/token" % oauth_uri
+
+  def __init__(self, auth=None):
+    super(CreateSend, self).__init__(auth)
 
   def apikey(self, site_url, username, password):
     """Gets your CreateSend API key, given your site url, username and password."""
