@@ -4,33 +4,9 @@ from urlparse import urlparse
 
 from createsend import *
 
-class CreateSendTestCase(unittest.TestCase):
-
-  def setUp(self):
-    self.api_key = '123123123123123123123'
-    self.base_uri = 'http://api.createsend.com/api/v3'
-    CreateSend.api_key = self.api_key
-    self.cs = CreateSend()
-    # Mapping of http status codes to the exceptions expected to be raised
-    self.error_responses = {
-      400: BadRequest,
-      401: Unauthorized,
-      404: NotFound,
-      500: ServerError }
-
-  def test_set_class_api_key(self):
-    self.cs.stub_request("systemdate.json", "systemdate.json")
-    systemdate = self.cs.systemdate()
-    self.assertEquals(self.cs.headers['Authorization'], "Basic %s" % base64.b64encode("%s:x" % self.api_key))
-    self.assertEquals(systemdate, "2010-10-15 09:27:00")
-
-  def test_set_instance_api_key(self):
-    CreateSend.api_key = None
-    self.cs.api_key = self.api_key
-    self.cs.stub_request("systemdate.json", "systemdate.json")
-    systemdate = self.cs.systemdate()
-    self.assertEquals(self.cs.headers['Authorization'], "Basic %s" % base64.b64encode("%s:x" % self.api_key))
-    self.assertEquals(systemdate, "2010-10-15 09:27:00")
+class CreateSendTestCase(object):
+  """CreateSend tests to be run in the context of both using an API key 
+  and using OAuth."""
 
   def test_apikey(self):
     site_url = "http://iamadesigner.createsend.com"
@@ -106,69 +82,85 @@ class CreateSendTestCase(unittest.TestCase):
     self.assertRaises(self.error_responses[500], self.cs.countries)
 
   def test_bad_request_on_post(self):
-    client = Client("uhiuhiuhiuhiuhiuhiuh")
+    client = Client(self.cs.auth_details, "uhiuhiuhiuhiuhiuhiuh")
     client.stub_request('clients.json', 'custom_api_error.json', status=400)
     self.assertRaises(self.error_responses[400], client.create, "Client Company Name",
       "(GMT+10:00) Canberra, Melbourne, Sydney", "Australia")
 
   def test_unauthorized_on_post(self):
-    client = Client("uhiuhiuhiuhiuhiuhiuh")
+    client = Client(self.cs.auth_details, "uhiuhiuhiuhiuhiuhiuh")
     client.stub_request('clients.json', 'custom_api_error.json', status=401)
     self.assertRaises(self.error_responses[401], client.create, "Client Company Name",
       "(GMT+10:00) Canberra, Melbourne, Sydney", "Australia")
 
   def test_not_found_on_post(self):
-    client = Client("uhiuhiuhiuhiuhiuhiuh")
+    client = Client(self.cs.auth_details, "uhiuhiuhiuhiuhiuhiuh")
     client.stub_request('clients.json', None, status=404)
     self.assertRaises(self.error_responses[404], client.create, "Client Company Name",
       "(GMT+10:00) Canberra, Melbourne, Sydney", "Australia")
 
   def test_server_error_on_post(self):
-    client = Client("uhiuhiuhiuhiuhiuhiuh")
+    client = Client(self.cs.auth_details, "uhiuhiuhiuhiuhiuhiuh")
     client.stub_request('clients.json', None, status=500)
     self.assertRaises(self.error_responses[500], client.create, "Client Company Name", 
       "(GMT+10:00) Canberra, Melbourne, Sydney", "Australia")
 
   def test_bad_request_on_put(self):
-    template = Template("uhiuhiuhiuhiuhiuhiuh")
+    template = Template(self.cs.auth_details, "uhiuhiuhiuhiuhiuhiuh")
     template.stub_request('templates/uhiuhiuhiuhiuhiuhiuh.json', 'custom_api_error.json', status=400)
     self.assertRaises(self.error_responses[400], template.update, "Template One Updated", "http://templates.org/index.html", 
       "http://templates.org/files.zip")
 
   def test_unauthorized_on_put(self):
-    template = Template("uhiuhiuhiuhiuhiuhiuh")
+    template = Template(self.cs.auth_details, "uhiuhiuhiuhiuhiuhiuh")
     template.stub_request('templates/uhiuhiuhiuhiuhiuhiuh.json', 'custom_api_error.json', status=401)
     self.assertRaises(self.error_responses[401], template.update, "Template One Updated", "http://templates.org/index.html", 
       "http://templates.org/files.zip")
 
   def test_not_found_on_put(self):
-    template = Template("uhiuhiuhiuhiuhiuhiuh")
+    template = Template(self.cs.auth_details, "uhiuhiuhiuhiuhiuhiuh")
     template.stub_request('templates/uhiuhiuhiuhiuhiuhiuh.json', None, status=404)
     self.assertRaises(self.error_responses[404], template.update, "Template One Updated", "http://templates.org/index.html", 
       "http://templates.org/files.zip")
 
   def test_server_error_on_put(self):
-    template = Template("uhiuhiuhiuhiuhiuhiuh")
+    template = Template(self.cs.auth_details, "uhiuhiuhiuhiuhiuhiuh")
     template.stub_request('templates/uhiuhiuhiuhiuhiuhiuh.json', None, status=500)
     self.assertRaises(self.error_responses[500], template.update, "Template One Updated", "http://templates.org/index.html", 
       "http://templates.org/files.zip")
   
   def test_bad_request_on_delete(self):
-    template = Template("uhiuhiuhiuhiuhiuhiuh")
+    template = Template(self.cs.auth_details, "uhiuhiuhiuhiuhiuhiuh")
     template.stub_request('templates/uhiuhiuhiuhiuhiuhiuh.json', 'custom_api_error.json', status=400)
     self.assertRaises(self.error_responses[400], template.delete)
 
   def test_unauthorized_on_delete(self):
-    template = Template("uhiuhiuhiuhiuhiuhiuh")
+    template = Template(self.cs.auth_details, "uhiuhiuhiuhiuhiuhiuh")
     template.stub_request('templates/uhiuhiuhiuhiuhiuhiuh.json', 'custom_api_error.json', status=401)
     self.assertRaises(self.error_responses[401], template.delete)
 
   def test_not_found_on_delete(self):
-    template = Template("uhiuhiuhiuhiuhiuhiuh")
+    template = Template(self.cs.auth_details, "uhiuhiuhiuhiuhiuhiuh")
     template.stub_request('templates/uhiuhiuhiuhiuhiuhiuh.json', None, status=404)
     self.assertRaises(self.error_responses[404], template.delete)
 
   def test_server_error_on_delete(self):
-    template = Template("uhiuhiuhiuhiuhiuhiuh")
+    template = Template(self.cs.auth_details, "uhiuhiuhiuhiuhiuhiuh")
     template.stub_request('templates/uhiuhiuhiuhiuhiuhiuh.json', None, status=500)
     self.assertRaises(self.error_responses[500], template.delete)
+
+class OAuthCreateSendTestCase(unittest.TestCase, CreateSendTestCase):
+  """Test when using OAuth to authenticate"""
+  def setUp(self):
+    self.cs = CreateSend({"access_token": "98u9q8uw9ddw", "refresh_token": "9u09i02e3"})
+    # Mapping of http status codes to the exceptions expected to be raised
+    self.error_responses = {
+      400: BadRequest, 401: Unauthorized, 404: NotFound, 500: ServerError }
+
+class ApiKeyCreateSendTestCase(unittest.TestCase, CreateSendTestCase):
+  """Test when using an API key to authenticate"""
+  def setUp(self):
+    self.cs = CreateSend({'api_key': '123123123123123123123'})
+    # Mapping of http status codes to the exceptions expected to be raised
+    self.error_responses = {
+      400: BadRequest, 401: Unauthorized, 404: NotFound, 500: ServerError }
