@@ -3,13 +3,7 @@ import urllib
 
 from createsend import *
 
-class SubscriberTestCase(unittest.TestCase):
-
-  def setUp(self):
-    self.api_key = '123123123123123123123'
-    CreateSend.api_key = self.api_key
-    self.list_id = "d98h2938d9283d982u3d98u88"
-    self.subscriber = Subscriber(self.list_id, "subscriber@example.com")
+class SubscriberTestCase(object):
 
   def test_get(self):
     email = "subscriber@example.com"
@@ -133,3 +127,19 @@ class SubscriberTestCase(unittest.TestCase):
     self.assertEquals(history[0].Actions[0].Date, "2010-10-12 13:18:00")
     self.assertEquals(history[0].Actions[0].IPAddress, "192.168.126.87")
     self.assertEquals(history[0].Actions[0].Detail, "")
+
+class OAuthSubscriberTestCase(unittest.TestCase, SubscriberTestCase):
+  """Test when using OAuth to authenticate"""
+  def setUp(self):
+    self.list_id = "d98h2938d9283d982u3d98u88"
+    self.subscriber = Subscriber(
+      {"access_token": "98u9q8uw9ddw", "refresh_token": "9u09i02e3"},
+      self.list_id, "subscriber@example.com")
+
+class ApiKeySubscriberTestCase(unittest.TestCase, SubscriberTestCase):
+  """Test when using an API key to authenticate"""
+  def setUp(self):
+    self.list_id = "d98h2938d9283d982u3d98u88"
+    self.subscriber = Subscriber(
+      {'api_key': '123123123123123123123'},
+      self.list_id, "subscriber@example.com")
